pub fn current_llm_optimization_recorder() -> Option<LlmOptimizationRecorder>Expand description
Return a recorder for the current execution intercept, if it is managed by Relay.
pub fn current_llm_optimization_recorder() -> Option<LlmOptimizationRecorder>Return a recorder for the current execution intercept, if it is managed by Relay.