ToolInterceptFn

Type Alias ToolInterceptFn 

pub type ToolInterceptFn = Arc<dyn Fn(String, Json) -> Pin<Box<dyn Future<Output = Result<Json>> + Send>> + Send + Sync>;
Rewrite tool arguments before execution.

Tool request intercepts run in priority order and can transform the JSON payload that is eventually passed into the tool execution callback.

Parameters

  • First argument: Tool name associated with the request.
  • Second argument: JSON argument payload to transform.

Returns

A Result containing the transformed JSON argument payload.

Errors

The callback can return any FlowError to abort the request-intercept chain.

Aliased Type

pub struct ToolInterceptFn { /* private fields */ }