pub struct ThreadScopeStackBinding { /* private fields */ }Expand description
Captured thread-local scope stack binding.
This preserves both the visible scope stack handle and whether it was explicitly installed on the current thread.
Implementations
Sourceimpl ThreadScopeStackBinding
impl ThreadScopeStackBinding
Sourcepub fn stack(&self) -> ScopeStackHandle
pub fn stack(&self) -> ScopeStackHandle
Return the captured thread-local scope stack handle.