pub struct EndScopeHandleParams<'a> {
pub handle: &'a ScopeHandle,
pub data: Option<Json>,
pub metadata: Option<Json>,
pub timestamp: Option<DateTime<Utc>>,
}Expand description
Builder parameters for [NemoRelayContextState::build_scope_end_event].
Fields
handle: &'a ScopeHandleScope handle to serialize into the emitted end event.
data: Option<Json>Optional JSON payload exported as the semantic scope output.
metadata: Option<Json>Optional metadata to be appended to the metadata set when the scope was created.
timestamp: Option<DateTime<Utc>>Optional timestamp recorded on the emitted end event. When omitted, the runtime records the current UTC time, or one microsecond after the handle start time if the current time is not later.
Implementations
Sourceimpl<'a> EndScopeHandleParams<'a>
impl<'a> EndScopeHandleParams<'a>
Sourcepub fn builder() -> EndScopeHandleParamsBuilder<'a, ((), (), (), ())>
pub fn builder() -> EndScopeHandleParamsBuilder<'a, ((), (), (), ())>
Create a builder for building EndScopeHandleParams.
On the builder, call .handle(...), .data(...)(optional), .metadata(...)(optional), .timestamp(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of EndScopeHandleParams.