pub struct PopScopeParams<'a> {
pub handle_uuid: &'a Uuid,
pub output: Option<Json>,
pub metadata: Option<Json>,
pub timestamp: Option<DateTime<Utc>>,
}Expand description
Builder parameters for pop_scope.
Fields
handle_uuid: &'a UuidUUID of the scope that should be popped.
output: Option<Json>Optional JSON payload exported as the semantic scope output.
metadata: Option<Json>Optional JSON payload metadata to be appended to the metadata set when the scope was created.
timestamp: Option<DateTime<Utc>>Optional timestamp recorded on the emitted end event. When omitted, the runtime records the current UTC time, or one microsecond after the handle start time if the current time is not later.
Implementations
Sourceimpl<'a> PopScopeParams<'a>
impl<'a> PopScopeParams<'a>
Sourcepub fn builder() -> PopScopeParamsBuilder<'a, ((), (), (), ())>
pub fn builder() -> PopScopeParamsBuilder<'a, ((), (), (), ())>
Create a builder for building PopScopeParams.
On the builder, call .handle_uuid(...), .output(...)(optional), .metadata(...)(optional), .timestamp(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of PopScopeParams.