pub struct ScopeAttributes(/* private fields */);Expand description
Bitflags that modify scope behavior and observability.
Implementations
Sourceimpl ScopeAttributes
impl ScopeAttributes
Sourcepub const PARALLEL: ScopeAttributes
pub const PARALLEL: ScopeAttributes
Marks the scope as running in parallel with sibling work.
Sourcepub const RELOCATABLE: ScopeAttributes
pub const RELOCATABLE: ScopeAttributes
Marks the scope as safe to move across execution contexts.
Sourceimpl ScopeAttributes
impl ScopeAttributes
Sourcepub const fn empty() -> ScopeAttributes
pub const fn empty() -> ScopeAttributes
Get a flags value with all bits unset.
Sourcepub const fn all() -> ScopeAttributes
pub const fn all() -> ScopeAttributes
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<ScopeAttributes>
pub const fn from_bits(bits: u32) -> Option<ScopeAttributes>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> ScopeAttributes
pub const fn from_bits_truncate(bits: u32) -> ScopeAttributes
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> ScopeAttributes
pub const fn from_bits_retain(bits: u32) -> ScopeAttributes
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ScopeAttributes>
pub fn from_name(name: &str) -> Option<ScopeAttributes>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ScopeAttributes) -> bool
pub const fn intersects(&self, other: ScopeAttributes) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ScopeAttributes) -> bool
pub const fn contains(&self, other: ScopeAttributes) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: ScopeAttributes)
pub fn insert(&mut self, other: ScopeAttributes)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: ScopeAttributes)
pub fn remove(&mut self, other: ScopeAttributes)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ScopeAttributes)
pub fn toggle(&mut self, other: ScopeAttributes)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ScopeAttributes, value: bool)
pub fn set(&mut self, other: ScopeAttributes, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ScopeAttributes) -> ScopeAttributes
pub const fn intersection(self, other: ScopeAttributes) -> ScopeAttributes
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ScopeAttributes) -> ScopeAttributes
pub const fn union(self, other: ScopeAttributes) -> ScopeAttributes
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: ScopeAttributes) -> ScopeAttributes
pub const fn difference(self, other: ScopeAttributes) -> ScopeAttributes
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ScopeAttributes,
) -> ScopeAttributes
pub const fn symmetric_difference( self, other: ScopeAttributes, ) -> ScopeAttributes
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ScopeAttributes
pub const fn complement(self) -> ScopeAttributes
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ScopeAttributes
impl ScopeAttributes
Sourcepub const fn iter(&self) -> Iter<ScopeAttributes> ⓘ
pub const fn iter(&self) -> Iter<ScopeAttributes> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ScopeAttributes> ⓘ
pub const fn iter_names(&self) -> IterNames<ScopeAttributes> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.