pub struct LlmOptimizationModelTransition {
pub baseline: Option<LlmOptimizationModel>,
pub effective: Option<LlmOptimizationModel>,
}Expand description
A model change proposed or applied by an optimizer.
Fields
baseline: Option<LlmOptimizationModel>Counterfactual model that would otherwise have served the request.
effective: Option<LlmOptimizationModel>Model selected by the optimization.