Module response

Module response 

Re-exported normalized LLM response data types and core pricing helpers.

Re-exports

pub use super::model_pricing::CacheReadAccounting;
pub use super::model_pricing::ModelPricing;
pub use super::model_pricing::PricingCatalog;
pub use super::model_pricing::PricingCatalogError;
pub use super::model_pricing::PricingConfig;
pub use super::model_pricing::PricingResolver;
pub use super::model_pricing::PricingSource;
pub use super::model_pricing::PricingSourceConfig;
pub use super::model_pricing::PricingUnit;
pub use super::model_pricing::PromptCachePricing;
pub use super::model_pricing::TokenPricingRates;
pub use super::model_pricing::active_pricing_resolver;
pub use super::model_pricing::attach_estimated_cost;
pub use super::model_pricing::attach_estimated_cost_for_provider;
pub use super::model_pricing::estimate_cost;
pub use super::model_pricing::estimate_cost_for_provider;
pub use super::model_pricing::estimate_cost_with_catalog;
pub use super::model_pricing::estimate_cost_with_provider;
pub use super::model_pricing::infer_model_provider;
pub use super::model_pricing::pricing_for_model;
pub use super::model_pricing::pricing_for_provider;
pub use super::model_pricing::reset_active_pricing_resolver;
pub use super::model_pricing::set_active_pricing_resolver;

Structs

AnnotatedLlmResponse
Structured view of an LLM response, produced by a response codec from raw JSON API output.
CostEstimate
Normalized LLM response cost.
ResponseToolCall
A tool call requested by the model in its response.
Usage
Token usage statistics from an LLM API response.

Enums

ApiSpecificResponse
API-specific response data that cannot be normalized across providers.
CostSource
Source of a normalized cost value.
FinishReason
Normalized reason why the model stopped generating.