pub enum EditorFieldKind {
Boolean,
String,
Integer,
Float,
Enum,
StringMap,
Json,
List,
TaggedUnion,
Section,
}Expand description
Editor control shape for one configuration field.
Variants
Boolean
Boolean toggle.
String
String-like value, including paths.
Integer
Integer value.
Float
Floating-point number value.
Enum
String enum with a fixed set of allowed values.
StringMap
Object with string keys and string values.
Json
Arbitrary JSON value.
List
A collection whose entries are edited recursively.
TaggedUnion
A tagged object whose variant is selected from a discriminator field.
Section
Nested configuration section.