pub struct EditorListItemSpec {
pub kind: EditorFieldKind,
pub schema: Option<fn() -> &'static EditorSchema>,
pub default: Option<fn() -> Value>,
pub tagged_union: Option<&'static EditorTaggedUnionSpec>,
pub list_item: Option<&'static EditorListItemSpec>,
}Expand description
Recursive metadata for one list entry.
Fields
kind: EditorFieldKindShape of each list entry.
schema: Option<fn() -> &'static EditorSchema>Schema used for object entries.
default: Option<fn() -> Value>Default value used for non-union entries.
tagged_union: Option<&'static EditorTaggedUnionSpec>Variant metadata when this list entry is a tagged union.
list_item: Option<&'static EditorListItemSpec>Nested list entry description when this item is itself a list.