pub fn load_native_plugins<I>(specs: I) -> Result<NativePluginActivation>where
I: IntoIterator<Item = NativePluginLoadSpec>,Expand description
Loads native dynamic plugins and registers their plugin kinds.
The returned activation must be kept alive until after active plugin configuration has been cleared.