pub fn record_active_plugin_runtime_diagnostic(diagnostic: RuntimeDiagnostic)Expand description
Record a bounded runtime diagnostic against the active plugin report.
pub fn record_active_plugin_runtime_diagnostic(diagnostic: RuntimeDiagnostic)Record a bounded runtime diagnostic against the active plugin report.