pub struct ConfigPolicy {
pub unknown_component: UnsupportedBehavior,
pub unknown_field: UnsupportedBehavior,
pub unsupported_value: UnsupportedBehavior,
}Expand description
Policy for how unsupported plugin/runtime config is handled.
Fields
unknown_component: UnsupportedBehaviorPolicy applied when a component kind is unknown to the plugin registry.
unknown_field: UnsupportedBehaviorPolicy applied when a known component contains an unknown field.
unsupported_value: UnsupportedBehaviorPolicy applied when a known field contains an unsupported value.