pub struct LocalBackendConfig {
pub python_module: Option<String>,
pub python_executable: Option<String>,
pub python_path: Option<String>,
}Expand description
Local-backend settings for the Python nemoguardrails runtime.
Fields
python_module: Option<String>Optional import path for the Python runtime module.
python_executable: Option<String>Optional Python executable used to run the local Guardrails worker.
python_path: Option<String>Optional PYTHONPATH used only by the local Guardrails worker subprocess.