pub fn with_scope_stack<T>(handle: ScopeStackHandle, f: impl FnOnce() -> T) -> TExpand description
Run a synchronous callback with handle as the visible scope stack.
This override takes precedence over task-local and thread-local stacks for the duration of the callback and is restored even when the callback panics.